@@ -85,7 +85,9 @@ class PayloadView():
 @click.command()
 def init():
     '''
-    For initiating the webhook operation 
+    For initiating the webhook operation \n
+    * Please store config.yaml in the directory \n
+    * Please create the clone of the repository  
     '''
     
     path=pathlib.Path().resolve()
@@ -125,12 +127,12 @@ def init():
         json_object = json.dumps(dictionary, indent = 4)
         
         # Writing to sample.json
-        with open("sample.json", "w") as outfile:
+        with open(project_id+'.json') as outfile:
             outfile.write(json_object)
         
     
 
-        with open('sample.json') as f:
+        with open(project_id+'.json') as f:
          data = json.load(f)
          username = data["username"]
          token=data["token"]
@@ -177,3 +179,18 @@ if __name__ == "__main__":
    
     server.serve_forever()
 
+
+
+import requests
+# Making a get request
+response = requests.get('http://35.225.89.124/push_commit')
+# print response
+print(response)
+# print elapsed time
+print(response.elapsed)
+
+from time import time, sleep
+while True:
+    sleep(60 - time() % 60)
+	# thing to run
+
